==> peperit_2.0_estable.zip: themes/peperit/html_files/componentes/escaparates/EscaparateLinea/lineaEscaparateLinea.php <==
<?php
//---------------------------------------------------------------------------------------------------------
// 26/Abril/2017
// Versión 1.0 Fichero que muestra los li de la lista de escaparates
//---------------------------------------------------------------------------------------------------------
/*
  Variables disponibles:
  $escaparateActual
  $nivel_maximo
  $condicion
  $activo
  $limite
  $nivel
 */
$hasChildren = '';
$columnas = 'col-md-4 col-lg-3';

if ($nivel == 0) {
    ?>
    {hijos}
    <?php
} else if ($nivel == 1) {
    
    if (count($escaparateActual->hijos) > 0) {
        $hasChildren = 'hasChildren';
    }
    ?>
    <li class="nivel_<?= $nivel; ?> v-megamenuitem <?= $hasChildren; ?> boton_esca">
        <a class="menu-title" href="<?= $escaparateActual->url; ?>"><?= mb_strtolower ($escaparateActual->nombre_natural); ?>
           <?php
        if (count($escaparateActual->hijos) > 0 && false) {
            ?> 
            <i class="mdi mdi-menu-down hidden-xs hidden-sm"></i>
            <?php
        }
        ?>  
        </a>
        <?php
        if (count($escaparateActual->hijos) > 0) {
            ?>
            <a href="#esca<?=$escaparateActual->codigo;?>" class="mdi mdi-minus-box collapsed " data-parent="#v-megamenu" data-toggle="collapse"></a>
            <?php
        }
        ?>  
          
        {hijos}
    </li>
   
    <?php
} else if ($nivel == 2) {
    ?>
    <li class=" columna">
        <a class="menu-item-title <?= $hasChildren; ?> olf" href="<?= $escaparateActual->url; ?>"><?= $escaparateActual->nombre_natural; ?>
         <?php
        if (count($escaparateActual->hijos) > 0) {
            ?>
            <i class="mdi mdi-play"></i>
            <?php
        }
        ?>
        </a>
        {hijos}
    </li>
    <?php
} else if ($nivel == 3) {
    ?>
    <li class = "columnaN3"><a class = "menu-item-title" href = "<?= $escaparateActual->url; ?>"><?= $escaparateActual->nombre_natural; ?></a></li>
    <?php
}
?>

==> peperit_2.1.02_estable.zip: themes/peperit/html_files/componentes/escaparates/EscaparateLinea/lineaEscaparateLinea.php <==
<?php
//---------------------------------------------------------------------------------------------------------
// 26/Abril/2017
// Versión 1.0 Fichero que muestra los li de la lista de escaparates
//---------------------------------------------------------------------------------------------------------
/*
  Variables disponibles:
  $escaparateActual
  $nivel_maximo
  $condicion
  $activo
  $limite
  $nivel
 */
$hasChildren = '';
$columnas = 'col-md-4 col-lg-3';

if ($nivel == 0) {
    ?>
    {hijos}
    <?php
} else if ($nivel == 1) {
    
    if (count($escaparateActual->hijos) > 0) {
        $hasChildren = 'hasChildren';
    }
    ?>
    <li class="nivel_<?= $nivel; ?> v-megamenuitem <?= $hasChildren; ?> boton_esca">
        <a class="menu-title" href="<?= $escaparateActual->url; ?>"><?= mb_strtolower ($escaparateActual->nombre_natural); ?>
           <?php
        if (count($escaparateActual->hijos) > 0 && false) {
            ?> 
            <i class="mdi mdi-menu-down hidden-xs hidden-sm"></i>
            <?php
        }
        ?>  
        </a>
        <?php
        if (count($escaparateActual->hijos) > 0) {
            ?>
            <a href="#esca<?=$escaparateActual->codigo;?>" class="mdi mdi-minus-box collapsed " data-parent="#v-megamenu" data-toggle="collapse"></a>
            <?php
        }
        ?>  
          
        {hijos}
    </li>
   
    <?php
} else if ($nivel == 2) {
    ?>
    <li class=" columna">
        <a class="menu-item-title <?= $hasChildren; ?> olf" href="<?= $escaparateActual->url; ?>"><?= $escaparateActual->nombre_natural; ?>
         <?php
        if (count($escaparateActual->hijos) > 0) {
            /*
            //Pedro 07/Septiembre/2020 ==> Añadimos la marca tal y como la tiene la plantilla
            ?>
            <i class="mdi mdi-play"></i>
            <?php
            */
            ?>
            <a href="javascript:$('#esca<?= $escaparateActual->codigo; ?>').toggle('slow');" class="opener"><i class="mdi mdi-play"></i></a>
            <?php
        }
        ?>
        </a>
        {hijos}
    </li>
    <?php
} else if ($nivel == 3) {
    ?>
    <li class = "columnaN3"><a class = "menu-item-title" href = "<?= $escaparateActual->url; ?>"><?= $escaparateActual->nombre_natural; ?></a></li>
    <?php
}
?>
